import { IVssRestClientOptions } from "../Common/Context";
import { RestClientBase } from "../Common/RestClientBase";
import * as Alert from "../Alert/Alert";
import * as WebApi from "../WebApi/WebApi";
export declare class AlertRestClient extends RestClientBase {
    constructor(options: IVssRestClientOptions);
    /**
     * Get an alert.
     *
     * @param project - Project ID or project name
     * @param alertId - ID of alert to retrieve
     * @param repository - Name or id  of a repository that alert is part of
     * @param ref -
     * @param expand - Expand alert attributes. Possible options are \{ValidationFingerprint, None\}
     */
    getAlert(project: string, alertId: number, repository: string, ref?: string, expand?: Alert.ExpandOption): Promise<Alert.Alert>;
    /**
     * Get alerts for a repository
     *
     * @param project - Project ID or project name
     * @param repository - The name or ID of the repository
     * @param top - The maximum number of alerts to return
     * @param orderBy - Must be "id" "firstSeen" "lastSeen" "fixedOn" or "severity"  Defaults to "id"
     * @param criteria - Options to limit the alerts returned
     * @param expand -
     * @param continuationToken - If there are more alerts than can be returned, a continuation token is placed in the "x-ms-continuationtoken" header.  Use that token here to get the next page of alerts
     */
    getAlerts(project: string, repository: string, top?: number, orderBy?: string, criteria?: Alert.SearchCriteria, expand?: Alert.AlertListExpandOption, continuationToken?: string): Promise<WebApi.PagedList<Alert.Alert>>;
    /**
     * Get an alert.
     *
     * @param project - Project ID or project name
     * @param alertId - ID of alert to retrieve
     * @param repository - Name or id  of a repository that alert is part of
     * @param ref -
     * @param expand - Expand alert attributes. Possible options are \{ValidationFingerprint, None\}
     */
    getAlertSarif(project: string, alertId: number, repository: string, ref?: string, expand?: Alert.ExpandOption): Promise<string>;
    /**
     * Update the status of an alert
     *
     * @param stateUpdate - The new status of the alert
     * @param project - Project ID or project name
     * @param alertId - The ID of the alert
     * @param repository - The name or ID of the repository
     */
    updateAlert(stateUpdate: Alert.AlertStateUpdate, project: string, alertId: number, repository: string): Promise<Alert.Alert>;
    /**
     * Returns the branches for which analysis results were submitted.
     *
     * @param project - Project ID or project name
     * @param repository -
     * @param alertType - The type of alert: Dependency Scanning (1), Secret (2), Code QL (3), etc.
     * @param continuationToken - A string variable that represents the branch name and is used to fetch branches that follow it in alphabetical order.
     * @param branchNameContains - A string variable used to fetch branches that contain this string anywhere in the branch name, case insensitive.
     * @param top - An int variable used to return the top k branches that satisfy the search criteria.
     * @param includePullRequestBranches - A bool variable indicating whether or not to include pull request branches.
     */
    getBranches(project: string, repository: string, alertType: Alert.AlertType, continuationToken?: string, branchNameContains?: string, top?: number, includePullRequestBranches?: boolean): Promise<Alert.Branch[]>;
    /**
     * @param project - Project ID or project name
     * @param repository -
     * @param alertType -
     */
    getUxFilters(project: string, repository: string, alertType: Alert.AlertType): Promise<Alert.UxFilters>;
    /**
     * Get instances of an alert on a branch specified with \@ref. If \@ref is not provided, return instances of an alert on default branch(if the alert exist in default branch) or latest affected branch.
     *
     * @param project - Project ID or project name
     * @param alertId - ID of alert to retrieve
     * @param repository - Name or id of a repository that alert is part of
     * @param ref -
     */
    getAlertInstances(project: string, alertId: number, repository: string, ref?: string): Promise<Alert.AlertAnalysisInstance[]>;
    /**
     * Create legal review. This creates the legal review associated with the alert. It include the review work item url.
     *
     * @param project - Project ID or project name
     * @param repository - Name or id  of a repository for the legal alert
     * @param alertId - Advance Security alert id of the legal alert to get the legal review
     * @param ref -
     */
    createLegalReview(project: string, repository: string, alertId: number, ref?: string): Promise<Alert.LegalReview>;
    /**
     * Update alert metadata associations.
     *
     * @param alertsMetadata - A list of metadata to associate with alerts.
     * @param project - Project ID or project name
     * @param repository - The name or ID of the repository.
     */
    updateAlertsMetadata(alertsMetadata: Alert.AlertMetadata[], project: string, repository: string): Promise<Alert.AlertMetadataChange[]>;
    /**
     * Upload a Sarif containing security alerts
     *
     * @param content - Content to upload
     * @param project - Project ID or project name
     * @param repository - The name or ID of a repository
     * @param notificationFlag - Header to signal that this is a progress notification
     */
    uploadSarif(content: string, project: string, repository: string, notificationFlag?: String): Promise<number>;
    /**
     * Get the status of the Sarif processing job
     *
     * @param sarifId - Sarif ID returned when the Sarif was uploaded
     */
    getSarif(sarifId: number): Promise<Alert.SarifUploadStatus>;
    /**
     * Get the validity details for an alert.
     *
     * @param project - Project ID or project name
     * @param repository - The name or ID of a repository
     * @param alertId - The ID of the alert
     */
    getValidityData(project: string, repository: string, alertId: number): Promise<Alert.ValidationRequestInfo>;
    /**
     * Initiate the validation process for a given alert
     *
     * @param project - Project ID or project name
     * @param repository - The name or ID of a repository
     * @param alertId - The ID of the alert
     */
    initiateValidation(project: string, repository: string, alertId: number): Promise<Alert.AlertValidationRequestStatus>;
}
